-- | A wrapper around darcs (for commands that require no input) that
-- detects the result (1, "No changes!\n" "") and turns it into (0,
-- "No changes!\n" ""), leaving other results the same.  This helps
-- distinguish code 1 from results like this:
-- @
--  darcs: ./_state.tmp/auth/open.lock: openBinaryFile: permission denied (Permission denied)
-- @
import System.IO (hGetContents, stdin, hPutStr, stderr)
import System.Environment (getArgs)
import System.Exit (ExitCode(ExitFailure), exitSuccess, exitWith)
import System.Process (readProcessWithExitCode)

main =
    do args <- getArgs
       (code, out, err) <- readProcessWithExitCode "/usr/bin/darcs" args ""
       case (code, out, err) of
         (ExitFailure 1, message, "")
           | elem "No changes!" (lines message) -> putStr out >> exitSuccess
         (n, out, err) -> putStr out >> hPutStr stderr err >> exitWith n
